.. _Tasks API:

Tasks API
=========

Each task must implement a TaskInterface
----------------------------------------

.. autoclass:: rkd.contract.TaskInterface
   :members:

Execution context provides parsed shell arguments and environment variables
---------------------------------------------------------------------------

.. autoclass:: rkd.contract.ExecutionContext
   :members:

Interaction with input and output
---------------------------------
.. autoclass:: rkd.inputoutput.IO
   :members:

